package com.example.pierre.myapplication;


import java.util.ArrayList;
import java.util.List;

        import android.content.ContentValues;
        import android.content.Context;
        import android.database.Cursor;
        import android.database.sqlite.SQLiteDatabase;

/*
 * class IngredientManager : méthode d'acces à la base de donnée
*/

public class IngredientManager {

    private static final String TABLE_NAME = "ingredient";
    private static final String KEY_ID = "_id";
    public static final String KEY_DESC = "desc";
    public static final String KEY_DLC = "dlc";
    public static final String KEY_DATE = "datemaj";
    public static final String CREATE_TABLE_INGREDIENT = "CREATE TABLE " + TABLE_NAME +
            " (" +
            " " + KEY_ID + " INTEGER primary key autoincrement," +
            " " + KEY_DESC + " TEXT," +
            " " + KEY_DLC + " TEXT," +
            " " + KEY_DATE + " TEXT" +
            ");";

    private String[] allColumns = {KEY_ID, KEY_DESC, KEY_DLC, KEY_DATE};
    private MySQLite maBaseSQLite; // notre gestionnaire du fichier SQLite
    private SQLiteDatabase db;

    // Constructeur
    public IngredientManager(Context context) {
        maBaseSQLite = MySQLite.getInstance(context);
    }

    public void open() {
        //on ouvre la table en lecture/écriture
        db = maBaseSQLite.getWritableDatabase();
    }

    public void close() {
        //on ferme l'accès à la BDD
        db.close();
    }

    public Ingredient addIngredient(String description, String dlc, String date) {
        // Ajout d'un enregistrement dans la table

        ContentValues values = new ContentValues();
        values.put(KEY_DESC, description);
        values.put(KEY_DLC, dlc);
        values.put(KEY_DATE, date);

        // insert() retourne l'id du nouvel enregistrement inséré, ou -1 en cas d'erreur
        long insertId = db.insert(TABLE_NAME, null, values);
        Cursor cursor = db.query(TABLE_NAME, allColumns, KEY_ID + " = "+ insertId, null, null, null,KEY_DLC + " DESC");
        cursor.moveToFirst();
        Ingredient newIngredient = cursorToIngredient(cursor);
        cursor.close();
        return newIngredient;
    }


    public int supIngredient(Ingredient ingredient) {
        // suppression d'un enregistrement
        // valeur de retour : (int) nombre de lignes affectées par la clause WHERE, 0 sinon

        String where = KEY_ID + " = ?";
        String[] whereArgs = {ingredient.getId() + ""};

        return db.delete(TABLE_NAME, where, whereArgs);
    }


    public List<Ingredient> getAllComments() {
        List<Ingredient> ingredients = new ArrayList<Ingredient>();

        Cursor cursor = db.query(TABLE_NAME,
                allColumns, null, null, null, null, KEY_DLC+" DESC");

        cursor.moveToFirst();
        while (!cursor.isAfterLast()) {
            Ingredient comment = cursorToIngredient(cursor);
            ingredients.add(comment);
            cursor.moveToNext();
        }
        cursor.close();
        return ingredients;
    }

    private Ingredient cursorToIngredient(Cursor cursor) {
        Ingredient ingredient = new Ingredient();
        ingredient.setId(cursor.getLong(0));
        ingredient.setDescription(cursor.getString(1));
        ingredient.setDlc(cursor.getString(2));
        ingredient.setDateMaj(cursor.getString(3));
        return ingredient;
    }
}
